@@ -86,6 +86,9 @@ void cmdline_read_history()
 {
     /// ヒストリを初期化 ///
     int i;
+    for(i=0; i<vector_size(gHistory); i++) {
+        string_delete(vector_item(gHistory, i));
+    }
     vector_clear(gHistory);
 
     /// ヒストリを.mhisotryから読み込む ///
@@ -129,8 +132,12 @@ void cmdline_read_history()
 
                 vector_add(gHistory, STRING_NEW(line2));
                 string_erase(line, 0, size2+1);
+
+                FREE(line2);
             }
         }
+
+        string_delete(line);
     }
 }
 
@@ -149,6 +156,17 @@ void cmdline_init()
 
 void cmdline_final()
 {
+    string_delete(gCmdLine);
+    string_delete(gCmdLineSaved);
+    int i;
+    for(i=0; i<vector_size(gHistory); i++) {
+        string_delete(vector_item(gHistory, i));
+    }
+    vector_delete(gHistory);
+    for(i=0; i<vector_size(gHCandidate); i++) {
+        string_delete(vector_item(gHCandidate, i));
+    }
+    vector_delete(gHCandidate);
 }
 
 void cmdline_start(char* str, int cursor, BOOL quick, BOOL continue_)
@@ -191,6 +209,9 @@ void cmdline_start(char* str, int cursor, BOOL quick, BOOL continue_)
     }
 
     int i;
+    for(i=0; i<vector_size(gHCandidate); i++) {
+        string_delete(vector_item(gHCandidate, i));
+    }
     vector_clear(gHCandidate);
 
     const int len = vector_size(gHistory);
@@ -230,7 +251,7 @@ void cmdline_convert()
         int des_size = strlen(src)*2 + 1;
         char* des = MALLOC(des_size + 1);
 #if defined(HAVE_ICONV_H) || defined(HAVE_BICONV_H) 
-        if(is_all_ascii(src)) {
+        if(is_all_ascii(kByte, src)) {
             xstrncpy(des, src, des_size);
         }
         else {
@@ -246,6 +267,8 @@ void cmdline_convert()
         if(string_length(gCmdLine) > kCmdLineMax) {
             string_trunc(gCmdLine, kCmdLineMax);
         }
+
+        FREE(des);
     }
 }
 
@@ -260,6 +283,7 @@ void cmdline_input(int meta, int key)
 
     if(key == 14 || key == KEY_DOWN) {    // CTRL-N
         if(gHistoryCursor == 0) {
+            string_delete(gCmdLine);
             gCmdLine = STRING_NEW(string_c_str(gCmdLineSaved));
             gCmdLineCursor = strlen(string_c_str(gCmdLine));
             gHistoryCursor = -1;
@@ -277,6 +301,7 @@ void cmdline_input(int meta, int key)
             gHistoryCursor = 0;
             gHistoryScrollTop = 0;
 
+            string_delete(gCmdLineSaved);
             gCmdLineSaved = STRING_NEW(string_c_str(gCmdLine));
         }
     }
@@ -546,11 +571,13 @@ void cmdline_input(int meta, int key)
 
         /// コマンド実行 ///
         saphire_set_signal();
-        sRFd* pipein = sRFd_new(STDIN_FILENO);
-        sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+        sRFd* pipein = RFD_NEW(STDIN_FILENO);
+        sWFd* pipeout = WFD_NEW(STDOUT_FILENO);
         int rcode = saphire_shell(string_c_str(gCmdLine), "cmdline", pipeout, pipein, STDERR_FILENO);
         saphire_sweep();
         sWFd_flash(pipeout);
+        sWFd_delete(pipeout);
+        sRFd_delete(pipein);
         add_history(string_c_str(gCmdLine));
         set_signal_mfiler();
 
@@ -607,6 +634,9 @@ void cmdline_input(int meta, int key)
 //    cmdline_convert();
 
     if(gHistoryCursor == -1) {
+        for(i=0; i<vector_size(gHCandidate); i++) {
+            string_delete(vector_item(gHCandidate, i));
+        }
         vector_clear(gHCandidate);
 
         len = vector_size(gHistory);
@@ -637,6 +667,7 @@ void cmdline_input(int meta, int key)
         string_obj* candidate = (string_obj*)vector_item(
                                              gHCandidate, gHistoryCursor);
         if(candidate) {
+            string_delete(gCmdLine);
             gCmdLine = STRING_NEW(string_c_str(candidate));
             gCmdLineCursor = strlen(string_c_str(gCmdLine));
         }
@@ -650,6 +681,9 @@ void cmdline_input(int meta, int key)
 void cmdline_hcandidate_refresh()
 {
     int i;
+    for(i=0; i<vector_size(gHCandidate); i++) {
+        string_delete(vector_item(gHCandidate, i));
+    }
     vector_clear(gHCandidate);
 
     int len = vector_size(gHistory);
@@ -701,6 +735,7 @@ static void cmdline_view_utf8_multi_line()
         
         /// 行の限界まできたら ///
         else if(line >= maxy) {
+            FREE(buf);
             break;
         }
 
@@ -736,6 +771,8 @@ static void cmdline_view_utf8_multi_line()
 
             mmvprintw(line, 0, "%s", line_top);
 
+            FREE(buf);
+
             break;
         }
 
@@ -743,6 +780,8 @@ static void cmdline_view_utf8_multi_line()
         else {
             n++;
         }
+
+        FREE(buf);
     }
 
     /// カーソル移動 ///
@@ -797,6 +836,8 @@ static void cmdline_view_utf8_2line()
 
                     mmvprintw(maxy-2, 2, "%s", line1);
                     mmvprintw(maxy-1, 0, "%s", pointer);
+
+                    FREE(line1);
                     break;
                 }
             }
@@ -868,12 +909,15 @@ static void cmdline_view_filer()
     
     char* env = getenv("PROMPT");
     if(env) {
-        string_obj* str = STRING_NEW("");
-        sRFd* rfd = sRFd_new(0);
-        saphire_shell3(str, env, "prompt", rfd);
+        sRFd* rfd = RFD_NEW(0);
+        sWFd* wfd = WFD_NEW(-1);
+        saphire_shell3(wfd, env, "prompt", rfd);
         saphire_sweep();
+        sRFd_delete(rfd);
 
-        mmvprintw(maxy -2, 0, "%s", string_c_str(str));
+        mmvprintw(maxy -2, 0, "%s", wfd->mBuffer);
+
+        sWFd_delete(wfd);
     }
 
     /// カーソル下のファイルの情報を描写 ///          
@@ -1020,6 +1064,8 @@ void cmdline_history_view()
         mmvprintw(line, 0, "%s", tmp);
         if(gHistoryCursor == i) mattroff();
         line--;
+
+        FREE(tmp);
         
         if(line < 0) {
             break;
