@@ -12,7 +12,7 @@
 #define lstat64 lstat
 #undef _LARGEFILE64_SOURCE
 
-#elif defined(__DARWIN__)
+#elif defined(__DARWIN__) || defined(__FREEBSD__)
 
 #define _LARGEFILE64_SOURCE       // サイズが大きいファイルを扱うために必要
 #include <sys/stat.h>     // ↑のマクロを使ってコンパイルしないといけない
