@@ -7,7 +7,7 @@
 #include <utime.h>
 #include <time.h>
 #include <sys/time.h>
-#if !defined(__DARWIN__)
+#if !defined(__DARWIN__) && !defined(__FREEBSD__)
 #include <sys/sysmacros.h>
 #endif
 #include <libgen.h>
