@@ -185,8 +185,8 @@ static void read_rc_file_compiled()
 
     snprintf(rc_fname, PATH_MAX, "%s/mfiler3.sao", SYSCONFDIR);
     if(access(rc_fname, R_OK) == 0) {
-        sRFd* pipein = sRFd_new(STDIN_FILENO);
-        sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+        sRFd* pipein = RFD_NEW(STDIN_FILENO);
+        sWFd* pipeout = WFD_NEW(STDOUT_FILENO);
         saphire_init_stack_frame();
         int rcode = saphire_load_obj(rc_fname
             , pipeout, pipein, STDERR_FILENO, NULL);
@@ -197,6 +197,9 @@ static void read_rc_file_compiled()
             fprintf(stderr, "%s\n", string_c_str(gErrMsg));
             exit(1);
         }
+
+        sRFd_delete(pipein);
+        sWFd_delete(pipeout);
     }
     else {
         fprintf(stderr, "can't find %s/mfiler3.sao file\n", SYSCONFDIR);
@@ -206,8 +209,8 @@ static void read_rc_file_compiled()
     snprintf(rc_fname, PATH_MAX, "%s/mfiler3.sao", gHomeDir);
 
     if(access(rc_fname, R_OK) == 0) {
-        sRFd* pipein = sRFd_new(STDIN_FILENO);
-        sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+        sRFd* pipein = RFD_NEW(STDIN_FILENO);
+        sWFd* pipeout = WFD_NEW(STDOUT_FILENO);
         saphire_init_stack_frame();
         int rcode = saphire_load_obj(rc_fname
             , pipeout, pipein, STDERR_FILENO, NULL);
@@ -217,6 +220,9 @@ static void read_rc_file_compiled()
             fprintf(stderr, "%s\n", string_c_str(gErrMsg));
             exit(1);
         }
+
+        sRFd_delete(pipein);
+        sWFd_delete(pipeout);
     }
 }
 
@@ -324,6 +330,8 @@ static void main_arg_e(char* send_cmd, int pid)
             }
             
             printf("%s", string_c_str(str));
+
+            string_delete(str);
         }
     }
 }
@@ -365,12 +373,14 @@ static void version()
 
 static void init_hooks()
 {
-    sRFd* pipein = sRFd_new(STDIN_FILENO);
-    sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+    sRFd* pipein = RFD_NEW(STDIN_FILENO);
+    sWFd* pipeout = WFD_NEW(STDOUT_FILENO);
     int rcode = saphire_shell(" def mcd_hook { true }; def atexit_hook { true }; def activate_hook { true }; def cursor_move_hook { true }; def cmdline_hook { true }", NULL, pipeout, pipein, STDERR_FILENO);
     saphire_sweep();
     sWFd_flash(pipeout);
 
+    sRFd_delete(pipein);
+    sWFd_delete(pipeout);
 }
 
 static void set_mfenv()
@@ -740,7 +750,7 @@ int main(int argc, char* argv[])
 #endif
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "4.4.2", 1);
+    setenv("VERSION", "4.4.6", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
@@ -936,12 +946,12 @@ int main(int argc, char* argv[])
         }
         else {
             saphire_set_signal();
-            string_obj* ret = STRING_NEW("");
-            sRFd* rfd = sRFd_new(0);
-            saphire_shell3(ret, " pidof mfiler3", "pidof mfiler3", rfd);
+            sWFd* wfd = WFD_NEW(-1);
+            sRFd* rfd = RFD_NEW(0);
+            saphire_shell3(wfd, " pidof mfiler3", "pidof mfiler3", rfd);
             saphire_sweep();
 
-            char* p = string_c_str(ret);
+            char* p = wfd->mBuffer;
             int pid = 0;
             while(*p) {
                 if(*p >= '0' && *p <= '9') {
@@ -955,6 +965,9 @@ int main(int argc, char* argv[])
                     p++;
                 }
             }
+
+            sWFd_delete(wfd);
+            sRFd_delete(rfd);
         }
 
         saphire_final();
@@ -1197,12 +1210,15 @@ int main(int argc, char* argv[])
                 mreset_tty();
 
                 saphire_set_signal();
-                sRFd* pipein = sRFd_new(STDIN_FILENO);
-                sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+                sRFd* pipein = RFD_NEW(STDIN_FILENO);
+                sWFd* pipeout = WFD_NEW(STDOUT_FILENO);
                 int rcode = saphire_shell(buf + 1, "mfiler3 -e", pipeout, pipein, STDERR_FILENO);
                 saphire_sweep();
                 sWFd_flash(pipeout);
 
+                sRFd_delete(pipein);
+                sWFd_delete(pipeout);
+
                 putp(tigetstr("rev"));
                 printf("HIT ANY KEY");
                 putp(tigetstr("sgr0"));
@@ -1225,15 +1241,18 @@ int main(int argc, char* argv[])
             }
             else if(buf[0] == 'e') {
                 saphire_set_signal();
-                string_obj* str = STRING_NEW("");
-                sRFd* rfd = sRFd_new(0);
-                saphire_shell3(str, buf + 1, "mfiler3 -E");
+                sWFd* wfd = WFD_NEW(-1);
+                sRFd* rfd = RFD_NEW(0);
+                saphire_shell3(wfd, buf + 1, "mfiler3 -E");
                 saphire_sweep();
                 saphire_sweep();
 
                 int pipe = open(pipe_name, O_WRONLY);
                 write(pipe, string_c_str(str), string_size(str) +1);
                 close(pipe);
+
+                sWFd_delete(wfd);
+                sRFd_delete(rfd);
             }
         }
 #endif
@@ -1243,9 +1262,9 @@ int main(int argc, char* argv[])
     }
 
     /// ごみソケットとパイプの掃除 ///
-    string_obj* ret = STRING_NEW("");
-    sRFd* rfd = sRFd_new(0);
-    saphire_shell3(ret, " pidof mfiler3", "clean mfiler3 sockets", rfd);
+    sRFd* rfd = RFD_NEW(0);
+    sWFd* wfd = WFD_NEW(-1);
+    saphire_shell3(wfd, " pidof mfiler3", "clean mfiler3 sockets", rfd);
     saphire_sweep();
 
     DIR* dir = opendir(gTempDir);
@@ -1262,7 +1281,7 @@ int main(int argc, char* argv[])
             if(pid != getpid()) {
                 char pid_buf[BUFSIZ];
                 snprintf(pid_buf, BUFSIZ, "%d", pid);
-                if(strstr(string_c_str(ret), pid_buf) == NULL) {
+                if(strstr(wfd->mBuffer, pid_buf) == NULL) {
                     char path[PATH_MAX];
                     snprintf(path, PATH_MAX, "%s/%s", gTempDir, entry->d_name);
                     unlink(path);
@@ -1275,7 +1294,7 @@ int main(int argc, char* argv[])
             if(pid != getpid()) {
                 char pid_buf[BUFSIZ];
                 snprintf(pid_buf, BUFSIZ, "%d", pid);
-                if(strstr(string_c_str(ret), pid_buf) == NULL) {
+                if(strstr(wfd->mBuffer, pid_buf) == NULL) {
                     char path[PATH_MAX];
                     snprintf(path, PATH_MAX, "%s/%s", gTempDir, entry->d_name);
                     unlink(path);
@@ -1284,6 +1303,9 @@ int main(int argc, char* argv[])
         }
     }
 
+    sWFd_delete(wfd);
+    sRFd_delete(rfd);
+
     closedir(dir);
 
     /// カーシス終わり ///
@@ -1294,18 +1316,19 @@ int main(int argc, char* argv[])
 
     /// フック呼び出し ///
     puts(""); // 見た目上のため
-    sRFd* pipein = sRFd_new(STDIN_FILENO);
-    sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+    sRFd* pipein = RFD_NEW(STDIN_FILENO);
+    sWFd* pipeout = WFD_NEW(STDOUT_FILENO);
     int rcode = saphire_shell("atexit_hook", NULL, pipeout, pipein, STDERR_FILENO);
     saphire_sweep();
     sWFd_flash(pipeout);
+    sWFd_delete(pipeout);
+    sRFd_delete(pipein);
     saphire_kill_all_jobs();
 
     /// モジュール解放 ///
     cmdline_final();
     cmdline_completion_final();
     isearch_final();
-    mcurses_final();
     kanji_final();
     menu_final();
     filer_final();
